@@ -1,4 +1,4 @@
-/* $Id: dgtboard.cc,v 1.16 2007/02/08 15:39:56 pierrebou Exp $ */
+/* $Id: dgtboard.cc,v 1.17 2008/02/08 15:10:46 bergo Exp $ */
 
 /*
 
@@ -111,18 +111,18 @@ bool loadDgtnix()
   const char *error;
   if (!dgtnix_dll_handle) 
     { 
-      count += snprintf(fErrorString+count,512-count,_("Unable to load dgtnix librairie.\n"));
-      count+= snprintf(fErrorString+count,512-count,"dlerror :%s\n",dlerror());
+      count += snprintf(fErrorString+count,512-count,_("Unable to load dgtnix library.\n"));
+      count+= snprintf(fErrorString+count,512-count,"dlerror: %s\n",dlerror());
       global.output->append(fErrorString,global.Colors.TextDefault,IM_NORMAL);
       return false;
     }
-  count += snprintf(fErrorString+count,512-count,_("Unable to load dgtnix librairie symbol.\n"));
+  count += snprintf(fErrorString+count,512-count,_("Unable to load dgtnix library symbol.\n"));
   dlerror();
   
   ptr_dgtnix_errno=(int *)dlsym(dgtnix_dll_handle, "dgtnix_errno");
   if(error = dlerror())
     {
-      count+= snprintf(fErrorString+count,512-count,"dgtnix_errno:%s\n",error);
+      count+= snprintf(fErrorString+count,512-count,"dgtnix_errno: %s\n",error);
       global.output->append(fErrorString,
 			    global.Colors.TextDefault,IM_NORMAL);
       dlclose(dgtnix_dll_handle);
@@ -132,7 +132,7 @@ bool loadDgtnix()
   *(void **)(&dgtnixQueryString) =  dlsym(dgtnix_dll_handle, "dgtnixQueryString");
   if(error = dlerror())
     {
-      count+= snprintf(fErrorString+count,512-count,"dgtnixQueryString:%s\n",error);
+      count+= snprintf(fErrorString+count,512-count,"dgtnixQueryString: %s\n",error);
       global.output->append(fErrorString,
 			    global.Colors.TextDefault,IM_NORMAL);
       dlclose(dgtnix_dll_handle);
@@ -143,7 +143,7 @@ bool loadDgtnix()
   if( version < requiredVersion)
     {
       char str[256];
-      snprintf(str,256,_("dgtnix version too old :%f, must be >= %f"), 
+      snprintf(str,256,_("dgtnix version too old: %f, must be >= %f"), 
 	       version, requiredVersion);
       global.output->append(str,global.Colors.TextDefault,IM_NORMAL);
       dlclose(dgtnix_dll_handle);
@@ -394,7 +394,7 @@ void dgtInit(const char *port,  MainWindow *mainWindow)
     }
   char msg[512];
   dgtnixSetOption(DGTNIX_DEBUG, DGTNIX_DEBUG_ON);
-  snprintf(msg,512,_("dgtnix driver version :%s"),
+  snprintf(msg,512,_("dgtnix driver version: %s"),
 	   dgtnixQueryString(DGTNIX_DRIVER_VERSION));
   global.output->append(msg,global.Colors.TextBright,IM_NORMAL);
   int fd = dgtnixInit(port);
