@@ -1,10 +1,10 @@
-/* $Id: dlg_gamelist.cc,v 1.29 2003/11/22 04:55:28 bergo Exp $ */
+/* $Id: dlg_gamelist.cc,v 1.37 2007/01/20 15:58:42 bergo Exp $ */
 
 /*
 
     eboard - chess client
     http://eboard.sourceforge.net
-    Copyright (C) 2000-2002 Felipe Paulo Guazzi Bergo
+    Copyright (C) 2000-2007 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -77,11 +77,14 @@ GameListDialog::GameListDialog(GameListListener *someone) {
 				 GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
 
   style=gtk_style_copy( gtk_widget_get_default_style() );
+
+  /* FIXME
   fixed=gdk_font_load("fixed");
   if (fixed)
     style->font=fixed;
   else
     cerr << _("<GameListDialog::GameListDialog> Warning: couldn't load fixed font, this dialog's content will look awful.\n\n");
+  */
 
   clist=gtk_clist_new(2);
   gtk_clist_set_shadow_type(GTK_CLIST(clist),GTK_SHADOW_IN);
@@ -116,7 +119,7 @@ GameListDialog::GameListDialog(GameListListener *someone) {
 
   setIcon(icon_games_xpm,_("Games"));
 
-  Gtk::show(bh,clist,sw,v,0);
+  Gtk::show(bh,clist,sw,v,NULL);
 
   gtk_signal_connect(GTK_OBJECT(widget),"delete_event",
 		     GTK_SIGNAL_FUNC(gamelist_delete),(gpointer)(&canclose));
@@ -136,7 +139,7 @@ GameListDialog::GameListDialog(GameListListener *someone) {
 void GameListDialog::appendGame(int gamenum, char *desc) {
   char z[10];
   char *zp[2];
-  sprintf(z,"%d",gamenum);
+  snprintf(z,10,"%d",gamenum);
   zp[0]=z;
   zp[1]=desc;
   gtk_clist_append(GTK_CLIST(clist),zp);
@@ -299,12 +302,14 @@ StockListDialog::StockListDialog(StockListListener *someone) {
 				 GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
 
   style=gtk_style_copy( gtk_widget_get_default_style() );
+  /* FIXME
   fixed=gdk_font_load("fixed");
   if (fixed)
     style->font=fixed;
   else
     cerr << _("<StockListDialog::StockListDialog> Warning: couldn't load fixed font, this dialog's content will look awful.\n\n");
-  
+  */
+
   // number(tree) displayed white black variant result
 
   clist=gtk_ctree_new(7,0);
@@ -349,7 +354,7 @@ StockListDialog::StockListDialog(StockListListener *someone) {
 
   setIcon(icon_local_xpm,_("Local"));
 
-  Gtk::show(clist,sw,v,left,h,0);
+  Gtk::show(clist,sw,v,left,h,NULL);
 
   gtk_signal_connect(GTK_OBJECT(widget),"delete_event",
 		     GTK_SIGNAL_FUNC(gamelist_delete),(gpointer)(&canclose));
@@ -417,10 +422,10 @@ void StockListDialog::refresh() {
   zp[6]=x;
 
   for(gli=global.GameList.begin();gli!=global.GameList.end();gli++) {
-    sprintf(x,"%d",(*gli)->GameNumber);
+    snprintf(x,16,"%d",(*gli)->GameNumber);
 
-    strcpy(y,(*gli)->getBoard()?_("Yes"):
-                                _("No"));
+    g_strlcpy(y,(*gli)->getBoard()?_("Yes"):
+	                           _("No"),8);
 
     strcpy(z,(*gli)->PlayerName[0]);
     strcpy(a,(*gli)->PlayerName[1]);
@@ -428,7 +433,7 @@ void StockListDialog::refresh() {
     strcpy(b,ChessGame::variantName((*gli)->Variant));
 
     if (!(*gli)->isOver())
-      strcpy(c,_("in progress"));
+      g_strlcpy(c,_("in progress"),16);
     else {
       GameResult gr=(*gli)->getResult();
       switch(gr) {
@@ -493,7 +498,6 @@ void StockListDialog::refresh() {
     snprintf(kb,256,"%s (%d %s)", ka, count[i], 
 	     count[i]==1?_("game"):
                          _("games"));
-    kb[255]=0;
       
     gtk_ctree_node_set_pixtext(GTK_CTREE(clist) , filenodes[i], 0, kb,
 			       4, icons[4], masks[4]);
@@ -502,27 +506,27 @@ void StockListDialog::refresh() {
   for(i=0;i<4;i++)
     gtk_ctree_node_set_text(GTK_CTREE(clist), toplevel[i], 6, "gtk-is-buggy");
 
-  sprintf(kb,_("From ICS (%d %s)"), kids[0], 
-	  kids[0]==1?_("game"):
-	  _("games"));
+  snprintf(kb,256,_("From ICS (%d %s)"), kids[0], 
+	   kids[0]==1?_("game"):
+	   _("games"));
   gtk_ctree_node_set_pixtext(GTK_CTREE(clist), toplevel[0], 0, kb, 
 			     4, icons[0],masks[0]);
 
-  sprintf(kb,_("From PGN Files (%d %s)"), 
-	  kids[1], kids[1]==1?_("game"):
-	  _("games"));
+  snprintf(kb,256,_("From PGN Files (%d %s)"), 
+	   kids[1], kids[1]==1?_("game"):
+	   _("games"));
   gtk_ctree_node_set_pixtext(GTK_CTREE(clist), toplevel[1], 0, kb,
 			     4, icons[1], masks[1]);
 
-  sprintf(kb,_("From Engines (%d %s)"), 
-	  kids[2], kids[2]==1?_("game"):
-	  _("games"));
+  snprintf(kb,256,_("From Engines (%d %s)"), 
+	   kids[2], kids[2]==1?_("game"):
+	   _("games"));
   gtk_ctree_node_set_pixtext(GTK_CTREE(clist), toplevel[2], 0, kb,
 			     4, icons[2], masks[2]);
 
-  sprintf(kb,_("From Elsewhere (%d %s)"), 
-	  kids[3], kids[3]==1?_("game"):
-	  _("games"));
+  snprintf(kb,256,_("From Elsewhere (%d %s)"), 
+	   kids[3], kids[3]==1?_("game"):
+	   _("games"));
   gtk_ctree_node_set_pixtext(GTK_CTREE(clist), toplevel[3], 0, kb,
 			     4, icons[3], masks[3]);
 
@@ -552,7 +556,7 @@ void StockListDialog::open() {
   b->walkBackAll();  
   cg->acknowledgeInfo();
   
-  sprintf(tab,_("Game #%d"),cg->GameNumber);
+  snprintf(tab,32,_("Game #%d"),cg->GameNumber);
   global.ebook->addPage(b->widget,tab,cg->GameNumber);
   b->setNotebook(global.ebook,cg->GameNumber);
   b->pop();
@@ -570,9 +574,6 @@ void StockListDialog::trashAll() {
     for(gli=global.GameList.begin();gli!=global.GameList.end();gli++) {
       cg=*gli;
       
-      if (!cg->isOver())
-	continue; // can't discard games in progress
-      
       if (cg->getBoard()) {
 	b=cg->getBoard();
 	
@@ -602,13 +603,10 @@ void StockListDialog::trash() {
   list<ChessGame *>::iterator gli;
 
   cg=global.getGame(SelectedRow);
-  if (!cg)
+  if (cg==NULL)
     return;
 
-  if (! cg->isOver())
-    return;
-
-  if (cg->getBoard()) {
+  if (cg->getBoard()!=NULL) {
     b=cg->getBoard();
 
     if (b==global.BoardList.front()) // can't remove game in main board
@@ -617,7 +615,7 @@ void StockListDialog::trash() {
     global.ebook->removePage(cg->GameNumber);
     global.removeBoard(b);
     delete(b);
-    cg->setBoard(0);
+    cg->setBoard(NULL);
   }
 
   for(gli=global.GameList.begin();gli!=global.GameList.end();gli++)
@@ -813,11 +811,14 @@ AdListDialog::AdListDialog(AdListListener *someone) {
 				 GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
 
   style=gtk_style_copy( gtk_widget_get_default_style() );
+
+  /* FIXME
   fixed=gdk_font_load("fixed");
   if (fixed)
     style->font=fixed;
   else
     cerr << _("<AdListDialog::AdListDialog> Warning: couldn't load fixed font, this dialog's content will look awful.\n\n");
+  */
 
   clist=gtk_clist_new(2);
   gtk_clist_set_shadow_type(GTK_CLIST(clist),GTK_SHADOW_IN);
@@ -852,7 +853,7 @@ AdListDialog::AdListDialog(AdListListener *someone) {
 
   setIcon(icon_ads_xpm,_("Ads"));
 
-  Gtk::show(bh,clist,sw,v,0);
+  Gtk::show(bh,clist,sw,v,NULL);
 
   gtk_signal_connect(GTK_OBJECT(widget),"delete_event",
 		     GTK_SIGNAL_FUNC(gamelist_delete),(gpointer)(&canclose));
@@ -872,7 +873,7 @@ AdListDialog::AdListDialog(AdListListener *someone) {
 void AdListDialog::appendGame(int gamenum, char *desc) {
   char z[10];
   char *zp[2];
-  sprintf(z,"%d",gamenum);
+  snprintf(z,10,"%d",gamenum);
   zp[0]=z;
   zp[1]=desc;
   gtk_clist_append(GTK_CLIST(clist),zp);
