@@ -1,10 +1,10 @@
-/* $Id: dlg_prefs.cc,v 1.49 2007/02/05 19:37:56 bergo Exp $ */
+/* $Id: dlg_prefs.cc,v 1.54 2008/02/22 07:32:15 bergo Exp $ */
 
 /*
 
     eboard - chess client
     http://eboard.sourceforge.net
-    Copyright (C) 2000-2007 Felipe Paulo Guazzi Bergo
+    Copyright (C) 2000-2008 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -62,7 +62,9 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
   GtkWidget *fl, *fv, *ft, *fn[NFONTS], *fb[NFONTS], *frv;
 
   // -- ics
-  GtkWidget *icv, *icl, *ict1, *icl1, *ifr1, *ifr2, *ifv1, *ifv2, *icl2, *icl3;
+  GtkWidget *icv, *icl, *ict1, *icl1, *ifr1, *ifr2, *ifv1, *ifv2, 
+    *icl2, *icl3,*spf, *sph;
+  GSList *spl;
 
   // -- sound
   static char *zcaption[]={N_("Opponent Moved"),
@@ -188,10 +190,13 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
 
   gtk_container_set_border_width(GTK_CONTAINER(icv),6);
 
-  ifr1=gtk_frame_new(_("Seek Table"));
+  ifr1=gtk_frame_new(_("Seek Graph"));
   gtk_frame_set_shadow_type(GTK_FRAME(ifr1),GTK_SHADOW_ETCHED_IN);
   ifr2=gtk_frame_new(_("Channel Tells"));
   gtk_frame_set_shadow_type(GTK_FRAME(ifr2),GTK_SHADOW_ETCHED_IN);
+  spf=gtk_frame_new(_("Non-ASCII Character Filtering"));
+  gtk_frame_set_shadow_type(GTK_FRAME(spf),GTK_SHADOW_ETCHED_IN);
+  sph=gtk_hbox_new(FALSE,2);
 
   ifv1=gtk_vbox_new(FALSE,2);
   ifv2=gtk_vbox_new(FALSE,2);
@@ -204,6 +209,9 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
   autologb=gtk_check_button_new_with_label(_("Run autofics.pl script after connecting to FICS"));
   gtk_box_pack_start(GTK_BOX(icv),autologb,FALSE,FALSE,2);
 
+  showts=gtk_check_button_new_with_label(_("Show timestamps for text lines"));
+  gtk_box_pack_start(GTK_BOX(icv),showts,FALSE,FALSE,2);
+
   /*
   allob[0]=gtk_check_button_new_with_label(FIXTRAN("Show observers on played games"));
   allob[1]=gtk_check_button_new_with_label(FIXTRAN("Show observers on observed games"));
@@ -212,12 +220,28 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
   gtk_box_pack_start(GTK_BOX(icv),allob[1],FALSE,FALSE,2);
   */
 
+  gtk_box_pack_start(GTK_BOX(icv),spf,FALSE,FALSE,2);
+  special[0] = gtk_radio_button_new_with_label(0,_("None"));
+  spl=gtk_radio_button_group(GTK_RADIO_BUTTON(special[0]));
+  special[1] = gtk_radio_button_new_with_label(spl,_("Truncate"));
+  spl=gtk_radio_button_group(GTK_RADIO_BUTTON(special[1]));
+  special[2] = gtk_radio_button_new_with_label(spl,_("Use underscores"));
+  spl=gtk_radio_button_group(GTK_RADIO_BUTTON(special[2]));
+  special[3] = gtk_radio_button_new_with_label(spl,_("Soft translate"));
+  spl=gtk_radio_button_group(GTK_RADIO_BUTTON(special[3]));
+
+  gtk_container_add(GTK_CONTAINER(spf),sph);
+  for(i=0;i<4;i++) {
+    gtk_box_pack_start(GTK_BOX(sph),special[i],FALSE,FALSE,2);
+    gshow(special[i]);
+  }
+
   gtk_box_pack_start(GTK_BOX(icv),ifr1,FALSE,FALSE,2);
 
-  sgb=gtk_check_button_new_with_label(_("Dynamic Seek Table"));
+  sgb=gtk_check_button_new_with_label(_("Dynamic Seek Graph"));
   gtk_box_pack_start(GTK_BOX(ifv1),sgb,FALSE,FALSE,2);
 
-  hsb=gtk_check_button_new_with_label(_("Inhibit seek lines on console when Seek Table is active"));
+  hsb=gtk_check_button_new_with_label(_("Inhibit seek lines on console when Seek Graph is active"));
   gtk_box_pack_start(GTK_BOX(ifv1),hsb,FALSE,FALSE,2);
 
   gtk_box_pack_start(GTK_BOX(icv),ifr2,FALSE,FALSE,2);
@@ -256,13 +280,15 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
   scr[1] = scrollBox(icv);
   Gtk::show(icl1, sbacke, icl2, lowtime, icl3, ict1,
 	    ifr1, ifr2, ifv1, ifv2,
-	    icl, showratb, autologb, /*allob[0], allob[1],*/
-	    sgb, chsb, coct, wget, hsb, icv, NULL);
+	    icl, showratb, autologb, showts, /*allob[0], allob[1],*/
+	    sgb, chsb, coct, wget, hsb, icv, spf, sph, NULL);
   
   gtk_notebook_append_page(GTK_NOTEBOOK(nb),scr[1],icl);
   
   gtset(GTK_TOGGLE_BUTTON(showratb), global.ShowRating?1:0);
   gtset(GTK_TOGGLE_BUTTON(autologb), global.FicsAutoLogin?1:0);
+  gtset(GTK_TOGGLE_BUTTON(showts),   global.ShowTimestamp?1:0);
+  gtset(GTK_TOGGLE_BUTTON(special[global.SpecialChars]), TRUE);
   /*
   gtset(GTK_TOGGLE_BUTTON(allob[0]), global.IcsAllObPlayed?1:0);
   gtset(GTK_TOGGLE_BUTTON(allob[1]), global.IcsAllObObserved?1:0);
@@ -353,7 +379,7 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
   gtk_entry_set_text(GTK_ENTRY(fn[3]),global.ConsoleFont);
   fb[3]=gtk_button_new_with_label(_("Choose..."));
 
-  fm[4]=new BoxedLabel(_("Seek Table Font"));
+  fm[4]=new BoxedLabel(_("Seek Graph Font"));
   gtk_entry_set_text(GTK_ENTRY(fn[4]),global.SeekFont);
   fb[4]=gtk_button_new_with_label(_("Choose..."));
 
@@ -624,6 +650,14 @@ void PreferencesDialog::Apply() {
     global.ebook->setTabPosition(ntp);
   }
 
+  for(i=0,nval=0;i<4;i++)
+    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(special[i]))) nval=i;
+
+  if (nval!=global.SpecialChars) {
+    global.SpecialChars = nval%4;
+    changed = 1;
+  }
+
   ApplyEntry(efont[0],global.ClockFont,96,&changed,NULL);
   ApplyEntry(efont[1],global.PlayerFont,96,&changed,NULL);
   ApplyEntry(efont[2],global.InfoFont,96,&changed,NULL);
@@ -636,6 +670,7 @@ void PreferencesDialog::Apply() {
   ApplyCheckBox(aqbar, &global.ShowQuickbar, &changed, NULL);
   ApplyCheckBox(showratb, &global.ShowRating, &changed, NULL);
   ApplyCheckBox(autologb, &global.FicsAutoLogin, &changed, NULL);
+  ApplyCheckBox(showts, &global.ShowTimestamp, &changed, &fchg);
   /*
   ApplyCheckBox(allob[0], &global.IcsAllObPlayed, &changed, NULL);
   ApplyCheckBox(allob[1], &global.IcsAllObObserved, &changed, NULL);
@@ -740,13 +775,15 @@ void PreferencesDialog::Apply() {
       if (global.network->isConnected())
 	global.protocol->refreshSeeks(true);
   
-  if (changed && global.IcsSeekGraph==0 && global.skgraph!=NULL)
-    global.skgraph->clear();
-  
-  if (schg && global.skgraph!=NULL) {
-    global.skgraph->updateFont();
-    global.skgraph->repaint();
+  if (changed && global.IcsSeekGraph==0 && global.skgraph2 != NULL) {
+    global.skgraph2->clear();
   }
+  
+  if (schg && global.skgraph2!=NULL) {
+    global.skgraph2->updateFont();
+    global.skgraph2->repaint();
+  }
+
   if (tbg)
     global.output->setBackground(global.Colors.Background);
 
