@@ -1,4 +1,4 @@
-/* $Id: main.cc,v 1.25 2007/01/20 15:58:43 bergo Exp $ */
+/* $Id: main.cc,v 1.27 2007/02/01 21:29:39 pierrebou Exp $ */
 
 /*
 
@@ -96,11 +96,11 @@ int main(int argc,char **argv) {
   if (global.PopupHelp)
     (new Help::GettingStarted())->show();
 
-  #ifdef WITH_DGT_BOARD
-  if (dgtport!=NULL)
+  if (dgtport!=NULL) {
     dgtInit(dgtport, z);
-  #endif
-
+    dgtSetBoard(global.BoardList.front());
+  }
+  
 #ifdef HAVE_LINUX_JOYSTICK_H
   openJoystick(z);
 #endif
