@@ -1,4 +1,4 @@
-/* $Id: network.cc,v 1.49 2007/02/05 20:15:16 bergo Exp $ */
+/* $Id: network.cc,v 1.50 2008/02/22 07:32:17 bergo Exp $ */
 
 /*
 
@@ -400,13 +400,16 @@ int DirectConnection::readLine(char *tbuffer,int limit) {
 
 void DirectConnection::writeLine(char *obuffer) {
   if (Connected) {
-    write(netsocket,obuffer,strlen(obuffer));
+    char *tmp;
+    tmp = global.filter(obuffer);
+    write(netsocket,tmp,strlen(tmp));
     write(netsocket,"\n",1);
     if (global.CommLog) {
       char z[4096];
-      snprintf(z,4096,"WROTE: %s",obuffer);
+      snprintf(z,4096,"WROTE: %s",tmp);
       global.LogAppend(z);
     }
+    if (tmp != obuffer) free(tmp);
   }
 }
 
@@ -525,13 +528,16 @@ int IncomingConnection::readLine(char *tbuffer, int limit) {
 
 void IncomingConnection::writeLine(char *obuffer) {
   if (Connected) {
-    write(netsocket,obuffer,strlen(obuffer));
+    char *tmp;
+    tmp = global.filter(obuffer);
+    write(netsocket,tmp,strlen(tmp));
     write(netsocket,"\n",1);
     if (global.CommLog) {
       char z[4096];
-      snprintf(z,4096,"WROTE: %s",obuffer);
+      snprintf(z,4096,"WROTE: %s",tmp);
       global.LogAppend(z);
     }
+    if (tmp!=obuffer) free(tmp);
   }
 }
 
@@ -862,17 +868,21 @@ void PipeConnection::writeLine(char *obuffer) {
   //  cerr << "writing [" << obuffer << "]\n";
   
   if (Connected) {
-    rem=strlen(obuffer);
+    char *tmp;
+    tmp = global.filter(obuffer);
+
+    rem=strlen(tmp);
     for(ew=0;rem;) {
-      ec=write(pout,obuffer+ew,rem);
+      ec=write(pout,tmp+ew,rem);
       if (ec<0) { usleep(50000); ++tol; if (tol==4) break; } else { ew+=ec; rem-=ec; }
     }
     write(pout,"\n",1);
     if (global.CommLog) {
       char z[4096];
-      snprintf(z,4096,"WROTE: %s",obuffer);
+      snprintf(z,4096,"WROTE: %s",tmp);
       global.LogAppend(z);
     }
+    if (tmp!=obuffer) free(tmp);
   }
 }
 
