@@ -1,10 +1,10 @@
-/* $Id: ntext.cc,v 1.19 2007/05/23 18:45:07 bergo Exp $ */
+/* $Id: ntext.cc,v 1.23 2008/02/22 14:34:29 bergo Exp $ */
 
 /*
 
     eboard - chess client
     http://eboard.sourceforge.net
-    Copyright (C) 2000-2007 Felipe Paulo Guazzi Bergo
+    Copyright (C) 2000-2008 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -39,6 +39,7 @@ NLine::NLine() {
   NBytes = 0;
   Color = 0;
   Width = -1;
+  time(&Timestamp);
 }
 
 NLine::NLine(const char *text, int color, int maxlen) {
@@ -49,6 +50,7 @@ NLine::NLine(const char *text, int color, int maxlen) {
   NBytes = strlen(Text);
   Color  = color;
   Width  = -1;
+  time(&Timestamp);
 }
 
 NLine::~NLine() {
@@ -60,15 +62,22 @@ FLine::FLine() {
   Text = NULL;
   NBytes = 0;
   Color = 0;
+  makeStamp();
 }
 
-FLine::FLine(const char *text, int color, int maxlen) {
+FLine::FLine(const char *text, int color, int maxlen, time_t stamp) {
   if (maxlen < 0)
     Text = g_strdup(text);
   else
     Text = g_strndup(text, maxlen);
   NBytes = strlen(Text);
   Color  = color;
+  if (stamp == 0)
+    time(&Timestamp);
+  else
+    Timestamp = stamp;
+
+  makeStamp();
 }
 
 FLine::FLine(NLine *src) {
@@ -78,6 +87,8 @@ FLine::FLine(NLine *src) {
     Text = NULL;
   NBytes = src->NBytes;
   Color  = src->Color;
+  Timestamp = src->Timestamp;
+  makeStamp();
 }
 
 void FLine::setSource(int src,int off) {
@@ -85,6 +96,12 @@ void FLine::setSource(int src,int off) {
   Off = off;
 }
 
+void FLine::makeStamp() {
+  struct tm *lt;
+  lt = localtime(&Timestamp);
+  snprintf(stamp,11,"[%.2d:%.2d:%.2d] ",lt->tm_hour,lt->tm_min,lt->tm_sec);
+}
+
 TPoint::TPoint() {
   LineNum = ByteOffset = 0;
 }
@@ -124,6 +141,7 @@ NText::NText() {
   lw = lh = 0;
   cw = ch = 0;  
   leftb = rightb = 1;
+  tsskip = -1;
   IgnoreChg = 0;
   WasAtBottom = true;
   MaxLines = 0;
@@ -216,7 +234,7 @@ void NText::setBG(int c) {
     repaint();
 }
 
-void NText::append(char *text, int len, int color) {
+void NText::append(const char *text, int len, int color) {
   int i;
   NLine *nl;
   char *p;
@@ -243,27 +261,29 @@ void NText::append(char *text, int len, int color) {
   lines.push_back(nl);
   formatLine(lines.size()-1);
   discardExcess();
-  fmtw = -1;
+  //fmtw = -1;
 }
 
 void NText::formatBuffer() {
   int i;
-  //Timestamp a,b,c;
+  //  Timestamp a,b,c;
 
-  //a = Timestamp::now();
+  //  a = Timestamp::now();
 
   for(i=0;i<xlines.size();i++)
     delete(xlines[i]);
   xlines.clear();
 
-  //b = Timestamp::now();
+  //  b = Timestamp::now();
+
+  tsskip = L.stringWidth(0,"[88:88:88] ");
 
   for(i=0;i<lines.size();i++)
     formatLine(i);
   fmtw = lw;
 
-  //c = Timestamp::now();
-  //cerr << "AB: " << b-a << "   BC: " << c-b << "  AC: " << c-a << endl;
+  //  c = Timestamp::now();
+  //  cerr << "AB: " << b-a << "   BC: " << c-b << "  AC: " << c-a << endl;
 }
 
 void NText::formatLine(unsigned int i) {
@@ -271,14 +291,22 @@ void NText::formatLine(unsigned int i) {
   bool fit = false;
   NLine *sl;
   FLine *fl;
+  const char *tp;
+  int elw;
+
 
   if (lines.size() <= i || canvas==NULL) // !font
     return;
 
   sl = lines[i];
 
-  j = 0;
+  elw = lw;
+  if (global.ShowTimestamp)
+    elw -= tsskip;
+
+  tp = sl->Text;
   k = sl->NBytes;
+  j = 0;
   color = sl->Color;
 
   // empty line
@@ -297,21 +325,23 @@ void NText::formatLine(unsigned int i) {
     if (j==0 && sl->Width >= 0) {
       w = sl->Width;
     } else {
-      w = L.substringWidth(0,sl->Text+j,k-j);
+      if (!g_utf8_validate(tp+j,k-j,NULL)) continue;
+      w = L.substringWidth(0,tp+j,k-j);
       if (j==0) sl->Width = w;
     }
-    if (w <= lw) {
-      fl = new FLine(sl->Text+j, color);
+    if (w <= elw) {
+      fl = new FLine(tp+j, color, -1, sl->Timestamp);
       fl->setSource(i,j);
       xlines.push_back(fl);
       return;
     }
 
     for(l=k-1;l>=j;l--)
-      if (sl->Text[l] == ' ' || sl->Text[l] == '\t') {
-	w = L.substringWidth(0,sl->Text+j,l-j);
-	if (w <= lw) {
-	  fl = new FLine(sl->Text+j,color,l-j);
+      if (tp[l] == ' ' || tp[l] == '\t') {
+	if (!g_utf8_validate(tp+j,k-j,NULL)) continue;
+	w = L.substringWidth(0,tp+j,l-j);
+	if (w <= elw) {
+	  fl = new FLine(tp+j,color,l-j, sl->Timestamp);
 	  fl->setSource(i,j);
 	  xlines.push_back(fl);
 	  j = l+1;
@@ -322,7 +352,7 @@ void NText::formatLine(unsigned int i) {
 
     // no blanks to wrap ?
     if (l<j && !fit) {
-      fl = new FLine(sl->Text+j,color);
+      fl = new FLine(tp+j,color,-1,sl->Timestamp);
       fl->setSource(i,j);
       xlines.push_back(fl);
       j = k;
@@ -557,7 +587,11 @@ void NText::selectRegion(int startline, int startoff, int endline, int endoff) {
   B.ByteOffset = endoff;
 
   havesel = true;
-  gtk_selection_owner_set(body, GDK_SELECTION_PRIMARY,time(0));
+  if (body != NULL) {
+    if (!GTK_WIDGET_REALIZED(body))
+      gtk_widget_realize(body);
+    gtk_selection_owner_set(body, GDK_SELECTION_PRIMARY,time(0));
+  }
   scheduleRepaint();
 }
 
@@ -602,7 +636,7 @@ gboolean ntext_configure(GtkWidget *widget, GdkEventConfigure *ee,
 {
   NText *me = (NText *) data;
   int i, j, ww, wh, fh, lb, ri;
-  int nl, tl, tb, ofh;
+  int nl, tl, tb, ofh, tk;
   GdkGC *gc;
   GdkPixmap *g;
   LayoutBox *L;
@@ -695,6 +729,8 @@ gboolean ntext_configure(GtkWidget *widget, GdkEventConfigure *ee,
       a=me->B; b=me->A;
     }
 
+  tk = global.ShowTimestamp ? me->tsskip : 0;
+
   for(i=0;i<nl;i++) {
     ri = i+tl;
     if (ri >= j)
@@ -702,10 +738,15 @@ gboolean ntext_configure(GtkWidget *widget, GdkEventConfigure *ee,
 
     fl = me->xlines[ri];
 
+    if (tk != 0) {
+      L->setColor(global.Colors.TextDefault);
+      L->drawString(lb,tb+fh*i,0,fl->stamp);
+    }
+
     L->setColor(fl->Color);
 
     if (!havesel) {
-      L->drawSubstring(lb,tb+fh*i,0,fl->Text,fl->NBytes);
+      L->drawSubstring(lb+tk,tb+fh*i,0,fl->Text,fl->NBytes);
     } else {
       
       c.LineNum = fl->Src;
@@ -715,7 +756,7 @@ gboolean ntext_configure(GtkWidget *widget, GdkEventConfigure *ee,
       d.ByteOffset = fl->Off + fl->NBytes - 1;
 
       if (b < c || d < a) 
-	L->drawSubstring(lb,tb+fh*i,0,fl->Text,fl->NBytes);
+	L->drawSubstring(lb+tk,tb+fh*i,0,fl->Text,fl->NBytes);
       else {
 
 	o1 = 0;
@@ -732,25 +773,25 @@ gboolean ntext_configure(GtkWidget *widget, GdkEventConfigure *ee,
 	if (o1 > 0) {
 	  ox = L->substringWidth(0,fl->Text,o1);
 	  L->setColor(fl->Color);
-	  L->drawSubstring(lb,tb+fh*i,0,fl->Text,o1);
+	  L->drawSubstring(lb+tk,tb+fh*i,0,fl->Text,o1);
 	}
 
 	pw = L->substringWidth(0,fl->Text+o1,o2-o1+1);
 	L->setColor(fl->Color);
-	L->drawRect(lb+ox,tb+fh*i,pw,fh,true);
+	L->drawRect(lb+ox+tk,tb+fh*i,pw,fh,true);
 	L->setColor(me->bgcolor);
-	L->drawSubstring(lb+ox,tb+fh*i,0,fl->Text+o1,o2-o1+1);
+	L->drawSubstring(lb+ox+tk,tb+fh*i,0,fl->Text+o1,o2-o1+1);
 
 	ox += pw;
 	L->setColor(fl->Color);
 
 	if (o2+1 != fl->NBytes)
-	  L->drawString(lb+ox,tb+fh*i,0,fl->Text+o2+1);
+	  L->drawString(lb+ox+tk,tb+fh*i,0,fl->Text+o2+1);
       }
     }
 
     fl->valid = true;
-    fl->X = lb;
+    fl->X = lb+tk;
     fl->Y = tb+fh*i;
     fl->H = fh;
   }
@@ -818,7 +859,7 @@ bool NText::calcTP(TPoint &t, int x,int y) {
 
   // set point at the end of text when the user clicks past the end */
   if (lastvalid >= 0) {
-    t.LineNum = lastvalid;
+    t.LineNum = xlines[lastvalid]->Src;
     t.ByteOffset = xlines[lastvalid]->NBytes - 1;
     return true;
   }
