@@ -1,4 +1,4 @@
-/* $Id: proto_xboard.cc,v 1.51 2007/02/05 20:19:19 bergo Exp $ */
+/* $Id: proto_xboard.cc,v 1.52 2008/02/08 14:25:51 bergo Exp $ */
 
 /*
 
@@ -171,10 +171,10 @@ void XBoardProtocol::receiveString(char *netstring) {
     if (timecontrol.mode == TC_SPM) {
       if (EngineWhite) bc=0; else wc=0;
     }
-    refgame->updatePosition(CurrentPosition, MoveNumber,
-			    EngineWhite?1:0, 
-			    wc,bc,
-			    _("illegal move!"));
+    refgame->updatePosition2(CurrentPosition, MoveNumber,
+			     EngineWhite?1:0, 
+			     wc,bc,
+			     _("illegal move!"));
     global.status->setText(netstring,15);
     global.BoardList.front()->setCanMove(true);
     return;
@@ -202,7 +202,7 @@ void XBoardProtocol::receiveString(char *netstring) {
     wc = bc = CLOCK_UNCHANGED;
     if (timecontrol.mode == TC_ICS) {
       if (MoveNumber == 1)
-	wc = bc = timecontrol.startValue();
+	wc = bc = 1000 * timecontrol.startValue();
       else
 	refgame->incrementActiveClock(timecontrol.value[1]);
     }    
@@ -210,10 +210,10 @@ void XBoardProtocol::receiveString(char *netstring) {
       if (EngineWhite) bc=0; else wc=0;
     }
 
-    refgame->updatePosition(CurrentPosition, MoveNumber,
-                            !MoveBlack, 
-			    wc, bc,
-			    b, true);
+    refgame->updatePosition2(CurrentPosition, MoveNumber,
+			     !MoveBlack, 
+			     wc, bc,
+			     b, true);
     advanceMove();
     global.BoardList.front()->setCanMove(true);
     global.opponentMoved();
@@ -276,7 +276,7 @@ void XBoardProtocol::sendMove(int x1,int y1,int x2,int y2,int prom) {
   wc = bc = CLOCK_UNCHANGED;
   if (timecontrol.mode == TC_ICS) {
     if (MoveNumber == 1)
-      wc = bc = timecontrol.startValue();
+      wc = bc = 1000 * timecontrol.startValue();
     else
       refgame->incrementActiveClock(timecontrol.value[1]);
   }
@@ -284,11 +284,11 @@ void XBoardProtocol::sendMove(int x1,int y1,int x2,int y2,int prom) {
     if (EngineWhite) wc=0; else bc=0;
   }
 
-  refgame->updatePosition(CurrentPosition,
-                          MoveNumber,
-                          !MoveBlack,
-			  wc,bc,
-			  ppfmm);
+  refgame->updatePosition2(CurrentPosition,
+			   MoveNumber,
+			   !MoveBlack,
+			   wc,bc,
+			   ppfmm);
   move[4]=0;
   move[5]=0;
   move[0]='a'+x1;
@@ -420,8 +420,8 @@ void XBoardProtocol::retractMove() {
       --MoveNumber;
       memset(z,0,64);
       p.getLastMove().copy(z,63);
-      ref->updatePosition(p,MoveNumber,MoveBlack,
-			  CLOCK_UNCHANGED, CLOCK_UNCHANGED,z);
+      ref->updatePosition2(p,MoveNumber,MoveBlack,
+			   CLOCK_UNCHANGED, CLOCK_UNCHANGED,z);
       global.network->writeLine("remove");
       global.status->setText(_("Retracted last move."),15);
       CurrentPosition = p;
@@ -675,10 +675,10 @@ void XBoardProtocol::createGame() {
     MoveBlack = pos->sidehint ? 0 : 1;
   }
 
-  cg->updatePosition(*pos,1,pos->sidehint ? 0:1,
-		     timecontrol.startValue(),
-		     timecontrol.startValue(),
-		     "0. startpos");
+  cg->updatePosition2(*pos,1,pos->sidehint ? 0:1,
+		      1000*timecontrol.startValue(),
+		      1000*timecontrol.startValue(),
+		      "0. startpos");
   delete pos;
 
   global.gameStarted();
@@ -1259,11 +1259,11 @@ void SjengProtocol::sendDrop(piece p,int x,int y) {
   else
     snprintf(ppfmm,32,"%d. %s",MoveNumber,mymove);
 
-  refgame->updatePosition(CurrentPosition, 
-                          MoveNumber,!MoveBlack,
-			  CLOCK_UNCHANGED,
-			  CLOCK_UNCHANGED,
-			  ppfmm);
+  refgame->updatePosition2(CurrentPosition, 
+			   MoveNumber,!MoveBlack,
+			   CLOCK_UNCHANGED,
+			   CLOCK_UNCHANGED,
+			   ppfmm);
 
   global.network->writeLine(mymove);
   advanceMove();
