@@ -1,4 +1,4 @@
-/* $Id: widgetproxy.cc,v 1.36 2007/01/20 15:58:43 bergo Exp $ */
+/* $Id: widgetproxy.cc,v 1.38 2007/05/23 18:28:17 bergo Exp $ */
 
 /*
 
@@ -52,6 +52,19 @@ void WidgetProxy::repaint() {
   gtk_widget_queue_resize(widget);
 }
 
+GtkWidget * WidgetProxy::scrollBox(GtkWidget *child) {
+  GtkWidget *scr;
+  scr = gtk_scrolled_window_new(NULL,NULL);
+  gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scr),
+				      GTK_SHADOW_NONE);
+  gtk_container_set_border_width(GTK_CONTAINER(scr),4);
+  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scr), 
+				 GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+  gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scr), child);
+  gtk_widget_show(scr);
+  return scr;
+}
+
 void WidgetProxy::setIcon(char **xpmdata,const char *text) {
   GdkPixmap *icon;
   GdkBitmap *mask;
@@ -539,6 +552,13 @@ void LayoutBox::prepare(GtkWidget *w, GdkPixmap *t, GdkGC *gc, int a, int b, int
   GC = gc;
   X=a; Y=b, W=c; H=d;
 
+  // leak, tomv
+  if (pl!=NULL)
+    g_object_unref(G_OBJECT(pl));
+  for(i=0;i<5;i++)
+    if (pfd[i]!=NULL)
+      pango_font_description_free(pfd[i]);
+
   for(i=0;i<5;i++)
     pfd[i] = NULL;
 
